@@ -1,4 +1,4 @@
-package core
+package core_test
 
 import (
 	"context"
@@ -7,6 +7,8 @@ import (
 	"testing"
 	"time"
 
+	"github.com/scaleway/scaleway-cli/v2/internal/core"
+
 	"github.com/alecthomas/assert"
 	"github.com/hashicorp/go-version"
 	"github.com/scaleway/scaleway-cli/v2/internal/args"
@@ -14,77 +16,77 @@ import (
 	"github.com/stretchr/testify/require"
 )
 
-var fakeCommand = &Command{
+var fakeCommand = &core.Command{
 	Namespace:            "plop",
 	ArgsType:             reflect.TypeOf(args.RawArgs{}),
 	AllowAnonymousClient: true,
 	Run: func(_ context.Context, _ interface{}) (i interface{}, e error) {
-		return &SuccessResult{}, nil
+		return &core.SuccessResult{}, nil
 	},
 }
 
 // These tests needs to run in sequence since they are modifying a file on the filesystem
 func Test_CheckVersion(t *testing.T) {
-	t.Run("Outdated version", Test(&TestConfig{
-		Commands: NewCommands(fakeCommand),
-		BuildInfo: &BuildInfo{
+	t.Run("Outdated version", core.Test(&core.TestConfig{
+		Commands: core.NewCommands(fakeCommand),
+		BuildInfo: &core.BuildInfo{
 			Version: version.Must(version.NewSemver("v1.20")),
 		},
 		Cmd: "scw plop",
-		Check: TestCheckCombine(
-			func(t *testing.T, ctx *CheckFuncCtx) {
+		Check: core.TestCheckCombine(
+			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				assert.Equal(t, "A new version of scw is available (2.5.4), beware that you are currently running 1.20.0\n", ctx.LogBuffer)
 			},
 		),
 		TmpHomeDir: true,
 	}))
 
-	t.Run("Up to date version", Test(&TestConfig{
-		Commands: NewCommands(fakeCommand),
-		BuildInfo: &BuildInfo{
+	t.Run("Up to date version", core.Test(&core.TestConfig{
+		Commands: core.NewCommands(fakeCommand),
+		BuildInfo: &core.BuildInfo{
 			Version: version.Must(version.NewSemver("v99.99")),
 		},
 		Cmd: "scw plop -D",
-		Check: TestCheckCombine(
-			func(t *testing.T, ctx *CheckFuncCtx) {
+		Check: core.TestCheckCombine(
+			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				assert.Contains(t, ctx.LogBuffer, "version is up to date (99.99.0)\n")
 			},
 		),
 		TmpHomeDir: true,
 	}))
 
-	t.Run("Already checked", Test(&TestConfig{
-		Commands: NewCommands(fakeCommand),
-		BuildInfo: &BuildInfo{
+	t.Run("Already checked", core.Test(&core.TestConfig{
+		Commands: core.NewCommands(fakeCommand),
+		BuildInfo: &core.BuildInfo{
 			Version: version.Must(version.NewSemver("v1.0")),
 		},
-		BeforeFunc: func(ctx *BeforeFuncCtx) error {
-			return createAndCloseFile(getLatestVersionUpdateFilePath(ctx.OverrideEnv[scw.ScwCacheDirEnv]))
+		BeforeFunc: func(ctx *core.BeforeFuncCtx) error {
+			return core.CreateAndCloseFile(core.GetLatestVersionUpdateFilePath(ctx.OverrideEnv[scw.ScwCacheDirEnv]))
 		},
 		Cmd: "scw plop -D",
-		Check: TestCheckCombine(
-			func(t *testing.T, ctx *CheckFuncCtx) {
+		Check: core.TestCheckCombine(
+			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				assert.Contains(t, ctx.LogBuffer, "version was already checked during past 24 hours\n")
 			},
 		),
 		TmpHomeDir: true,
 	}))
 
-	t.Run("Check more than 24h ago", Test(&TestConfig{
-		Commands: NewCommands(fakeCommand),
-		BuildInfo: &BuildInfo{
+	t.Run("Check more than 24h ago", core.Test(&core.TestConfig{
+		Commands: core.NewCommands(fakeCommand),
+		BuildInfo: &core.BuildInfo{
 			Version: version.Must(version.NewSemver("v1.0")),
 		},
-		BeforeFunc: func(ctx *BeforeFuncCtx) error {
-			filePath := getLatestVersionUpdateFilePath(ctx.OverrideEnv[scw.ScwCacheDirEnv])
-			err := createAndCloseFile(filePath)
+		BeforeFunc: func(ctx *core.BeforeFuncCtx) error {
+			filePath := core.GetLatestVersionUpdateFilePath(ctx.OverrideEnv[scw.ScwCacheDirEnv])
+			err := core.CreateAndCloseFile(filePath)
 			require.NoError(t, err)
 			twoDaysAgo := time.Now().Local().Add(-2 * time.Hour * 24)
 			return os.Chtimes(filePath, twoDaysAgo, twoDaysAgo)
 		},
 		Cmd: "scw plop",
-		Check: TestCheckCombine(
-			func(t *testing.T, ctx *CheckFuncCtx) {
+		Check: core.TestCheckCombine(
+			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				assert.Contains(t, ctx.LogBuffer, "A new version of scw is available (2.5.4), beware that you are currently running 1.0.0\n")
 			},
 		),
