@@ -1,4 +1,4 @@
-package core
+package core_test
 
 import (
 	"context"
@@ -7,6 +7,8 @@ import (
 	"testing"
 	"time"
 
+	"github.com/scaleway/scaleway-cli/v2/internal/core"
+
 	"github.com/scaleway/scaleway-cli/v2/internal/args"
 )
 
@@ -19,11 +21,11 @@ type testDate struct {
 	Date *time.Time
 }
 
-func testGetCommands() *Commands {
-	return NewCommands(
-		&Command{
+func testGetCommands() *core.Commands {
+	return core.NewCommands(
+		&core.Command{
 			Namespace: "test",
-			ArgSpecs: ArgSpecs{
+			ArgSpecs: core.ArgSpecs{
 				{
 					Name: "name-id",
 				},
@@ -34,10 +36,10 @@ func testGetCommands() *Commands {
 				return "", nil
 			},
 		},
-		&Command{
+		&core.Command{
 			Namespace: "test",
 			Resource:  "positional",
-			ArgSpecs: ArgSpecs{
+			ArgSpecs: core.ArgSpecs{
 				{
 					Name:       "name-id",
 					Positional: true,
@@ -52,7 +54,7 @@ func testGetCommands() *Commands {
 				return argsI, nil
 			},
 		},
-		&Command{
+		&core.Command{
 			Namespace:            "test",
 			Resource:             "raw-args",
 			ArgsType:             reflect.TypeOf(args.RawArgs{}),
@@ -69,7 +71,7 @@ func testGetCommands() *Commands {
 				return res, nil
 			},
 		},
-		&Command{
+		&core.Command{
 			Namespace:            "test",
 			Resource:             "date",
 			ArgsType:             reflect.TypeOf(testDate{}),
@@ -83,36 +85,36 @@ func testGetCommands() *Commands {
 }
 
 func Test_handleUnmarshalErrors(t *testing.T) {
-	t.Run("underscore", Test(&TestConfig{
+	t.Run("underscore", core.Test(&core.TestConfig{
 		Commands: testGetCommands(),
 		Cmd:      "scw test name_id",
-		Check: TestCheckCombine(
-			TestCheckExitCode(1),
-			TestCheckError(&CliError{
+		Check: core.TestCheckCombine(
+			core.TestCheckExitCode(1),
+			core.TestCheckError(&core.CliError{
 				Err:  fmt.Errorf("invalid argument 'name_id': arg name must only contain lowercase letters, numbers or dashes"),
 				Hint: "Valid arguments are: name-id",
 			}),
 		),
 	}))
 
-	t.Run("value only", Test(&TestConfig{
+	t.Run("value only", core.Test(&core.TestConfig{
 		Commands: testGetCommands(),
 		Cmd:      "scw test ubuntu_focal",
-		Check: TestCheckCombine(
-			TestCheckExitCode(1),
-			TestCheckError(&CliError{
+		Check: core.TestCheckCombine(
+			core.TestCheckExitCode(1),
+			core.TestCheckError(&core.CliError{
 				Err:  fmt.Errorf("invalid argument 'ubuntu_focal': arg name must only contain lowercase letters, numbers or dashes"),
 				Hint: "Valid arguments are: name-id",
 			}),
 		),
 	}))
 
-	t.Run("relative date", Test(&TestConfig{
+	t.Run("relative date", core.Test(&core.TestConfig{
 		Commands: testGetCommands(),
 		Cmd:      "scw test date date=+3R",
-		Check: TestCheckCombine(
-			TestCheckExitCode(1),
-			TestCheckError(&CliError{
+		Check: core.TestCheckCombine(
+			core.TestCheckExitCode(1),
+			core.TestCheckError(&core.CliError{
 				Message: "could not parse +3R as either an absolute time (RFC3339) nor a relative time (+/-)RFC3339",
 				Details: `Absolute time error: parsing time "+3R" as "2006-01-02T15:04:05Z07:00": cannot parse "+3R" as "2006"
 Relative time error: unknown unit in duration: "R"
@@ -125,80 +127,80 @@ Relative time error: unknown unit in duration: "R"
 }
 
 func Test_RawArgs(t *testing.T) {
-	t.Run("Simple", Test(&TestConfig{
+	t.Run("Simple", core.Test(&core.TestConfig{
 		Commands: testGetCommands(),
 		Cmd:      "scw test raw-args -- blabla",
-		Check: TestCheckCombine(
-			TestCheckExitCode(0),
-			TestCheckStdout("blabla\n"),
+		Check: core.TestCheckCombine(
+			core.TestCheckExitCode(0),
+			core.TestCheckStdout("blabla\n"),
 		),
 	}))
-	t.Run("Multiple", Test(&TestConfig{
+	t.Run("Multiple", core.Test(&core.TestConfig{
 		Commands: testGetCommands(),
 		Cmd:      "scw test raw-args -- blabla foo bar",
-		Check: TestCheckCombine(
-			TestCheckExitCode(0),
-			TestCheckStdout("blabla foo bar\n"),
+		Check: core.TestCheckCombine(
+			core.TestCheckExitCode(0),
+			core.TestCheckStdout("blabla foo bar\n"),
 		),
 	}))
 }
 
 func Test_PositionalArg(t *testing.T) {
 	t.Run("Error", func(t *testing.T) {
-		t.Run("Missing1", Test(&TestConfig{
+		t.Run("Missing1", core.Test(&core.TestConfig{
 			Commands: testGetCommands(),
 			Cmd:      "scw test positional",
-			Check: TestCheckCombine(
-				TestCheckExitCode(1),
-				TestCheckError(&CliError{
+			Check: core.TestCheckCombine(
+				core.TestCheckExitCode(1),
+				core.TestCheckError(&core.CliError{
 					Err:  fmt.Errorf("a positional argument is required for this command"),
 					Hint: "Try running: scw test positional <name-id>",
 				}),
 			),
 		}))
 
-		t.Run("Missing2", Test(&TestConfig{
+		t.Run("Missing2", core.Test(&core.TestConfig{
 			Commands: testGetCommands(),
 			Cmd:      "scw test positional tag=world",
-			Check: TestCheckCombine(
-				TestCheckExitCode(1),
-				TestCheckError(&CliError{
+			Check: core.TestCheckCombine(
+				core.TestCheckExitCode(1),
+				core.TestCheckError(&core.CliError{
 					Err:  fmt.Errorf("a positional argument is required for this command"),
 					Hint: "Try running: scw test positional <name-id> tag=world",
 				}),
 			),
 		}))
 
-		t.Run("Invalid1", Test(&TestConfig{
+		t.Run("Invalid1", core.Test(&core.TestConfig{
 			Commands: testGetCommands(),
 			Cmd:      "scw test positional name-id=plop tag=world",
-			Check: TestCheckCombine(
-				TestCheckExitCode(1),
-				TestCheckError(&CliError{
+			Check: core.TestCheckCombine(
+				core.TestCheckExitCode(1),
+				core.TestCheckError(&core.CliError{
 					Err:  fmt.Errorf("a positional argument is required for this command"),
 					Hint: "Try running: scw test positional plop tag=world",
 				}),
 			),
 		}))
 
-		t.Run("Invalid2", Test(&TestConfig{
+		t.Run("Invalid2", core.Test(&core.TestConfig{
 			Commands: testGetCommands(),
 			Cmd:      "scw test positional tag=world name-id=plop",
-			Check: TestCheckCombine(
-				TestCheckExitCode(1),
-				TestCheckError(&CliError{
+			Check: core.TestCheckCombine(
+				core.TestCheckExitCode(1),
+				core.TestCheckError(&core.CliError{
 					Err:  fmt.Errorf("a positional argument is required for this command"),
 					Hint: "Try running: scw test positional plop tag=world",
 				}),
 			),
 		}))
 
-		t.Run("Invalid3", Test(&TestConfig{
+		t.Run("Invalid3", core.Test(&core.TestConfig{
 			Commands: testGetCommands(),
 			Cmd:      "scw test positional plop name-id=plop",
-			Check: TestCheckCombine(
-				TestCheckExitCode(1),
-				TestCheckError(&CliError{
+			Check: core.TestCheckCombine(
+				core.TestCheckExitCode(1),
+				core.TestCheckError(&core.CliError{
 					Err:  fmt.Errorf("a positional argument is required for this command"),
 					Hint: "Try running: scw test positional plop",
 				}),
@@ -206,42 +208,42 @@ func Test_PositionalArg(t *testing.T) {
 		}))
 	})
 
-	t.Run("simple", Test(&TestConfig{
+	t.Run("simple", core.Test(&core.TestConfig{
 		Commands: testGetCommands(),
 		Cmd:      "scw test positional plop",
-		Check:    TestCheckExitCode(0),
+		Check:    core.TestCheckExitCode(0),
 	}))
 
-	t.Run("full command", Test(&TestConfig{
+	t.Run("full command", core.Test(&core.TestConfig{
 		Commands: testGetCommands(),
 		Cmd:      "scw test positional plop tag=world",
-		Check:    TestCheckExitCode(0),
+		Check:    core.TestCheckExitCode(0),
 	}))
 
-	t.Run("full command", Test(&TestConfig{
+	t.Run("full command", core.Test(&core.TestConfig{
 		Commands: testGetCommands(),
 		Cmd:      "scw test positional -h",
-		Check: TestCheckCombine(
-			TestCheckExitCode(0),
-			TestCheckGolden(),
+		Check: core.TestCheckCombine(
+			core.TestCheckExitCode(0),
+			core.TestCheckGolden(),
 		),
 	}))
 
-	t.Run("multi positional", Test(&TestConfig{
+	t.Run("multi positional", core.Test(&core.TestConfig{
 		Commands: testGetCommands(),
 		Cmd:      "scw test positional tag=tag01 test1 test2",
-		Check: TestCheckCombine(
-			TestCheckExitCode(0),
-			TestCheckGolden(),
+		Check: core.TestCheckCombine(
+			core.TestCheckExitCode(0),
+			core.TestCheckGolden(),
 		),
 	}))
 
-	t.Run("multi positional json", Test(&TestConfig{
+	t.Run("multi positional json", core.Test(&core.TestConfig{
 		Commands: testGetCommands(),
 		Cmd:      "scw test positional -o json tag=tag01 test1 test2",
-		Check: TestCheckCombine(
-			TestCheckExitCode(0),
-			TestCheckGolden(),
+		Check: core.TestCheckCombine(
+			core.TestCheckExitCode(0),
+			core.TestCheckGolden(),
 		),
 	}))
 }
