@@ -1,14 +1,16 @@
-package iot
+package iot_test
 
 import (
 	"testing"
 
+	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/iot/v1"
+
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
 )
 
 func Test_CreateNetwork(t *testing.T) {
 	t.Run("Simple", core.Test(&core.TestConfig{
-		Commands:   GetCommands(),
+		Commands:   iot.GetCommands(),
 		BeforeFunc: createHub(),
 		Cmd:        "scw iot network create hub-id={{ .Hub.ID }} type=sigfox topic-prefix=foo",
 		Check:      core.TestCheckGolden(),
