@@ -1,15 +1,17 @@
-package vpcgw
+package vpcgw_test
 
 import (
 	"testing"
 
+	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/vpcgw/v1"
+
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/vpc/v2"
 	"github.com/scaleway/scaleway-cli/v2/internal/testhelpers"
 )
 
-func Test_vpcGwGatewayGet(t *testing.T) {
-	cmds := GetCommands()
+func Test_vpcGwGatewayNetworkGet(t *testing.T) {
+	cmds := vpcgw.GetCommands()
 	cmds.Merge(vpc.GetCommands())
 
 	t.Run("Simple", core.Test(&core.TestConfig{
@@ -17,13 +19,15 @@ func Test_vpcGwGatewayGet(t *testing.T) {
 		BeforeFunc: core.BeforeFuncCombine(
 			testhelpers.CreatePN(),
 			testhelpers.CreateGateway("GW"),
-			testhelpers.CreateGatewayNetwork("GW"),
+			testhelpers.CreateDHCP(),
+			testhelpers.CreateGatewayNetworkDHCP("GW"),
 		),
-		Cmd:   "scw vpc-gw gateway get {{ .GW.ID }}",
+		Cmd:   "scw vpc-gw gateway-network get {{ .GWNT.ID }}",
 		Check: core.TestCheckGolden(),
 		AfterFunc: core.AfterFuncCombine(
 			testhelpers.DeleteGatewayNetwork(),
 			testhelpers.DeletePN(),
+			testhelpers.DeleteDHCP(),
 			testhelpers.DeleteGateway("GW"),
 			testhelpers.DeleteIPVpcGw("GW"),
 		),
